==> zope.generations-4.0.tar.gz: zope.generations-4.0/setup.py <==
##############################################################################
#
# Copyright (c) 2006 Zope Foundation and Contributors.
# All Rights Reserved.
#
# This software is subject to the provisions of the Zope Public License,
# Version 2.1 (ZPL).  A copy of the ZPL should accompany this distribution.
# THIS SOFTWARE IS PROVIDED "AS IS" AND ANY AND ALL EXPRESS OR IMPLIED
# WARRANTIES ARE DISCLAIMED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF TITLE, MERCHANTABILITY, AGAINST INFRINGEMENT, AND FITNESS
# FOR A PARTICULAR PURPOSE.
#
##############################################################################
# This package is developed by the Zope Toolkit project, documented here:
# http://docs.zope.org/zopetoolkit
# When developing and releasing this package, please follow the documented
# Zope Toolkit policies as described by this documentation.
##############################################################################
"""Setup for zope.generations package
"""
import os
from setuptools import setup, find_packages


def read(*rnames):
    with open(os.path.join(os.path.dirname(__file__), *rnames)) as f:
        return f.read()


setup(name='zope.generations',
      version='4.0',
      author='Zope Corporation and Contributors',
      author_email='zope-dev@zope.org',
      description='Zope application schema generations',
      long_description=(
          read('README.txt')
          + '\n\n.. contents::\n\n' +
          '======================\n'
          'Detailed Documentation\n'
          '======================\n'
          + '\n\n' +
          read('src', 'zope', 'generations', 'README.txt')
          + '\n\n' +
          read('CHANGES.txt')
      ),
      keywords="zope zodb schema generation",
      classifiers=[
          'Development Status :: 5 - Production/Stable',
          'Environment :: Web Environment',
          'Intended Audience :: Developers',
          'License :: OSI Approved :: Zope Public License',
          'Programming Language :: Python',
          'Programming Language :: Python :: 2',
          'Programming Language :: Python :: 2.7',
          'Programming Language :: Python :: 3',
          'Programming Language :: Python :: 3.4',
          'Programming Language :: Python :: 3.5',
          'Programming Language :: Python :: 3.6',
          'Programming Language :: Python :: Implementation :: CPython',
          'Programming Language :: Python :: Implementation :: PyPy',
          'Natural Language :: English',
          'Operating System :: OS Independent',
          'Topic :: Internet :: WWW/HTTP',
          'Framework :: Zope3'],
      url='http://pypi.python.org/pypi/zope.generations',
      license='ZPL 2.1',
      packages=find_packages('src'),
      package_dir={'': 'src'},
      namespace_packages=['zope'],
      extras_require=dict(test=[
          'ZODB',
          'zope.site',
          'zope.testing',
      ]),
      install_requires=[
          'setuptools',
          'transaction',
          'zope.component',
          'zope.interface',
          'zope.processlifetime',
      ],
      tests_require=[
          'ZODB',
          'zope.site',
          'zope.testing',
          'zope.testrunner',
      ],
      include_package_data=True,
      zip_safe=False,
      )

==> zope.generations-4.1.0.tar.gz: zope.generations-4.1.0/setup.py <==
##############################################################################
#
# Copyright (c) 2006 Zope Foundation and Contributors.
# All Rights Reserved.
#
# This software is subject to the provisions of the Zope Public License,
# Version 2.1 (ZPL).  A copy of the ZPL should accompany this distribution.
# THIS SOFTWARE IS PROVIDED "AS IS" AND ANY AND ALL EXPRESS OR IMPLIED
# WARRANTIES ARE DISCLAIMED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF TITLE, MERCHANTABILITY, AGAINST INFRINGEMENT, AND FITNESS
# FOR A PARTICULAR PURPOSE.
#
##############################################################################
# This package is developed by the Zope Toolkit project, documented here:
# http://docs.zope.org/zopetoolkit
# When developing and releasing this package, please follow the documented
# Zope Toolkit policies as described by this documentation.
##############################################################################
"""Setup for zope.generations package
"""
import os
from setuptools import setup, find_packages


def read(*rnames):
    with open(os.path.join(os.path.dirname(__file__), *rnames)) as f:
        return f.read()


setup(name='zope.generations',
      version='4.1.0',
      author='Zope Corporation and Contributors',
      author_email='zope-dev@zope.org',
      description='Zope application schema generations',
      long_description=(
          read('README.rst')
          + '\n\n.. contents::\n\n' +
          '======================\n'
          'Detailed Documentation\n'
          '======================\n'
          + '\n\n' +
          read('src', 'zope', 'generations', 'README.rst')
          + '\n\n' +
          read('CHANGES.rst')
      ),
      keywords="zope zodb schema generation",
      classifiers=[
          'Development Status :: 5 - Production/Stable',
          'Environment :: Web Environment',
          'Intended Audience :: Developers',
          'License :: OSI Approved :: Zope Public License',
          'Programming Language :: Python',
          'Programming Language :: Python :: 2',
          'Programming Language :: Python :: 2.7',
          'Programming Language :: Python :: 3',
          'Programming Language :: Python :: 3.4',
          'Programming Language :: Python :: 3.5',
          'Programming Language :: Python :: 3.6',
          'Programming Language :: Python :: 3.7',
          'Programming Language :: Python :: Implementation :: CPython',
          'Programming Language :: Python :: Implementation :: PyPy',
          'Natural Language :: English',
          'Operating System :: OS Independent',
          'Topic :: Internet :: WWW/HTTP',
          'Framework :: Zope :: 3'],
      url='https://github.com/zopefoundation/zope.generations',
      license='ZPL 2.1',
      packages=find_packages('src'),
      package_dir={'': 'src'},
      namespace_packages=['zope'],
      extras_require=dict(test=[
          'ZODB',
          'zope.site',
          'zope.testing',
      ]),
      install_requires=[
          'setuptools',
          'transaction',
          'zope.component',
          'zope.interface',
          'zope.processlifetime',
      ],
      tests_require=[
          'ZODB',
          'zope.site',
          'zope.testing',
          'zope.testrunner',
      ],
      include_package_data=True,
      zip_safe=False,
      )
